@@ -29,7 +29,9 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import re
-from ..linter import ERROR, NOTICE
+import os
+from lxml import etree as ET
+from ..linter import ERROR, WARNING, NOTICE
 from ..cmake import argparse as cmake_argparse
 from .misc import project
 
@@ -64,6 +66,40 @@ def depends(linter):
     linter.add_init_hook(on_init)
 
 
+def launch_depends(linter):
+
+    # We assume that the following packages are always present in a sane ROS environment, so we do
+    # not litter the log with warnings about missing exec_depends if these are used in launch files
+    essential_packages = set(["rosbag", "rosnode", "rosservice", "rostopic"])
+
+    def on_final(info):
+        for dirpath, dirnames, filenames in os.walk(info.path, topdown=True):
+            for filename in filenames:
+                fl = filename.lower()
+                if fl.endswith(".launch") and "test" not in fl and "example" not in fl:
+                    full_filename = os.path.join(dirpath, filename)
+                    src_filename = os.path.relpath(full_filename, info.path)
+                    with open(full_filename, "r") as f:
+                        content = f.read()
+                        try:
+                            root = ET.fromstring(content)
+                            for node in root.getiterator():
+                                if node.tag is not ET.Comment:
+                                    pkg = node.get("pkg")
+                                    if pkg is not None and pkg != info.manifest.name and info.env.is_catkin_pkg(pkg) and pkg not in info.exec_dep and pkg not in essential_packages:
+                                        info.report(WARNING, "LAUNCH_DEPEND", type="exec" if info.manifest.package_format > 1 else "run", pkg=pkg, file_location=(src_filename, node.sourceline or 0))
+                                    for mo in re.finditer(r"\$\(find\s+([^<>)]+)\)", "<>".join(node.values() + [node.text or "", node.tail or ""])):
+                                        pkg = mo.group(1)
+                                        if pkg is not None and pkg != info.manifest.name and info.env.is_catkin_pkg(pkg) and pkg not in info.exec_dep and pkg not in essential_packages:
+                                            info.report(WARNING, "LAUNCH_DEPEND", type="exec" if info.manifest.package_format > 1 else "run", pkg=pkg, file_location=(src_filename, node.sourceline or 0))
+                        except ET.Error as err:
+                            info.report(WARNING, "PARSE_ERROR", msg=str(err), file_location=(src_filename, 0))
+            dirnames[:] = [d for d in dirnames if not d.startswith(".") and "test" not in d and "build" not in d and "example" not in d]
+
+    linter.require(depends)
+    linter.add_final_hook(on_final)
+
+
 def catkin_build(linter):
     def on_init(info):
         info.uses_catkin = False
@@ -246,6 +282,7 @@ def package_description(linter):
 
 def all(linter):
     linter.require(depends)
+    linter.require(launch_depends)
     linter.require(catkin_build)
     linter.require(export_targets)
     linter.require(package_description)
