@@ -273,6 +273,13 @@ message_list = {
         Your package uses features of another package but you
         failed to list this dependency in your package.xml
         """),
+    "LAUNCH_DEPEND":
+    ("launch configuration needs %(type)s_depend on '%(pkg)s'",
+        """\
+        Your package refers to another package in one of its
+        launch files, but you do not have this dependency in your
+        package.xml
+        """),
     "UNCONFIGURED_BUILD_DEPEND":
     ("unconfigured build_depend on '%(pkg)s'",
         """\
@@ -280,6 +287,13 @@ message_list = {
         call find_package() nor have it listed as catkin component in
         the find_package(catkin) call.
         """),
+    "MISCONFIGURED_CATKIN_PACKAGE":
+    ("misconfigured catkin package '%(pkg)s'",
+        """\
+        You use an unsupported way to include a catkin package in your build. Even though this
+        might work in your particular case, you should use the proper
+        find_package() mechanism to make sure that all relevant CMake macros will be run.
+        """),
     "WRONG_DEPEND":
     ("%(wrong_type)s_depend '%(pkg)s' should be a %(right_type)s_depend",
         """\
@@ -580,6 +594,11 @@ message_list = {
         An operating system error has occured. This is not a linting problem per se but
         might be caused by a missing or unreadable file.
         """),
+    "PARSE_ERROR":
+    ("parse error: %(msg)s",
+        """\
+        Your package has a malformed file that could not be processed for linting.
+        """),
     "ENDBLOCK_ARGS":
     ("extra arguments in %(cmd)s()",
         """\
@@ -637,3 +656,9 @@ def msg(msg_id, **kwargs):
     text, explanation = message_list[msg_id]
     explanation = re.sub(r"\s+", " ", explanation).strip()
     return (msg_id, text % kwargs, explanation % kwargs)
+
+
+def add_user_defined_msg(msg_id, text, explanation):
+    if msg_id in message_list:
+        raise ValueError("duplicate message ID: %s" % msg_id)
+    message_list[msg_id] = (text, explanation)
