@@ -36,7 +36,7 @@ import string
 from fnmatch import fnmatch
 from copy import copy
 from .cmake import ParserContext, argparse as cmake_argparse, CMakeSyntaxError
-from .diagnostics import msg
+from .diagnostics import msg, add_user_defined_msg
 
 ERROR = 0
 WARNING = 1
@@ -98,6 +98,7 @@ class LintInfo(object):
         self.executables = set()
         self.libraries = set()
         self.static_libraries = set()
+        self.interface_libraries = set()
         self.conditionals = []
         self.var = {}
         self.parent_var = {}
@@ -260,6 +261,15 @@ class CMakeLinter(object):
         check(self)
         self._catch_circular_deps.remove(check)
 
+    def register_message(self, msg_id, text, description=None):
+        if not re.match(r"X_[A-Z0-9_]+$", msg_id):
+            raise ValueError("custom message IDs must start with X_ and only use the characters [A-Z0-9_]")
+        if not text:
+            raise ValueError("message text for %s must not be empty" % msg_id)
+        if re.search(r"[\r\n\t]", text):
+            raise ValueError("message text for %s must not contain TAB or newline characters" % msg_id)
+        add_user_defined_msg(msg_id, text, description or "This message has been defined by a third-party plugin and has no description")
+
     def add_init_hook(self, cb):
         self._init_hooks.append(cb)
 
@@ -413,7 +423,6 @@ class CMakeLinter(object):
                     first = max(0, len(items) + first)
                 if length == -1 or first + length > len(items):
                     length = len(items) - first
-                print(first,length)
                 info.var[output] = ";".join(items[first:first + length])
                 return
             else:
@@ -508,14 +517,16 @@ class CMakeLinter(object):
                     info.find_packages.add(args[0])
                 if cmd == "add_executable":
                     info.targets.add(args[0])
-                    if "IMPORTED" not in args:
+                    if "IMPORTED" not in args and "ALIAS" not in args:
                         info.executables.add(args[0])
                 if cmd == "add_library":
                     info.targets.add(args[0])
-                    if "IMPORTED" not in args:
+                    if "IMPORTED" not in args and "ALIAS" not in args and "OBJECT" not in args:
                         info.libraries.add(args[0])
                         if "STATIC" in args:
                             info.static_libraries.add(args[0])
+                        if "INTERFACE" in args:
+                            info.interface_libraries.add(args[0])
                 if cmd == "add_custom_target":
                     info.targets.add(args[0])
                 if cmd == "find_path":
