@@ -1,29 +1,27 @@
 import unittest
-from .helper import create_env, create_manifest, mock_lint, patch
-
-import sys
-sys.stderr = sys.stdout
-import os
-
-from tempfile import mkdtemp
 import shutil
 import argparse
+import os
+from .helper import create_env, create_manifest, mock_lint, patch
+from tempfile import mkdtemp
 try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO
 from catkin_lint.main import prepare_arguments, run_linter
 import catkin_lint.environment
+import catkin_lint.ros
+
 
 class AllChecksTest(unittest.TestCase):
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/package-path/mock/src/source.cpp"))
     def test_project(self):
         """Test minimal catkin project for compliance"""
-        env = create_env(catkin_pkgs=[ "catkin", "foo", "foo_msgs" ])
-        pkg = create_manifest("mock", description="Cool Worf", build_depends=[ "foo", "foo_msgs" ], run_depends=[ "foo_msgs" ])
+        env = create_env(catkin_pkgs=["catkin", "foo", "foo_msgs"])
+        pkg = create_manifest("mock", description="Cool Worf", build_depends=["foo", "foo_msgs"], run_depends=["foo_msgs"])
         result = mock_lint(env, pkg,
-            """\
+                           """\
             project(mock)
             find_package(catkin REQUIRED COMPONENTS foo foo_msgs)
             catkin_package(CATKIN_DEPENDS foo_msgs)
@@ -37,10 +35,10 @@ class AllChecksTest(unittest.TestCase):
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/package-path/mock/src/source.cpp"))
     def test_project_with_skip(self):
         """Test minimal catkin project with skip directive"""
-        env = create_env(catkin_pkgs=[ "catkin", "foo", "foo_msgs" ])
-        pkg = create_manifest("mock", description="Cool Worf", build_depends=[ "foo", "foo_msgs" ], run_depends=[ "foo_msgs" ])
+        env = create_env(catkin_pkgs=["catkin", "foo", "foo_msgs"])
+        pkg = create_manifest("mock", description="Cool Worf", build_depends=["foo", "foo_msgs"], run_depends=["foo_msgs"])
         result = mock_lint(env, pkg,
-            """\
+                           """\
             project(mock)
             find_package(catkin REQUIRED COMPONENTS foo foo_msgs)
             catkin_package(CATKIN_DEPENDS foo_msgs)
@@ -69,15 +67,23 @@ class DummyDist(object):
             </package>'''
         return None
 
+
 def get_dummy_index_url():
     return "http://127.0.0.1:9"
 
+
 def get_dummy_index(url):
     return None
 
+
 def get_dummy_cached_distribution(index, dist_name, cache=None, allow_lazy_load=False):
     return DummyDist()
 
+
+def raise_io_error(*args):
+    raise IOError("mock exception")
+
+
 class CatkinInvokationTest(unittest.TestCase):
 
     def fake_package(self, name, depends, wsdir):
@@ -106,33 +112,36 @@ class CatkinInvokationTest(unittest.TestCase):
             f.write("Random executable file")
         os.chmod(os.path.join(pkgdir, ".git", "script"), 0o755)
 
-    def raise_io_error(self, *args):
-        raise IOError("mock exception")
-
     @patch("rosdistro.get_index_url", get_dummy_index_url)
     @patch("rosdistro.get_index", get_dummy_index)
     @patch("rosdistro.get_cached_distribution", get_dummy_cached_distribution)
     def run_catkin_lint(self, *argv):
+        print("RUN:" + " ".join(argv))
         catkin_lint.environment._cache = None  # force cache reloads
+        catkin_lint.ros._rosdistro_cache = {}
         parser = prepare_arguments(argparse.ArgumentParser())
         args = parser.parse_args(argv)
         stdout = StringIO()
         with patch("sys.stdout", stdout):
             with patch("sys.stderr", stdout):
                 returncode = run_linter(args)
+        print(stdout.getvalue())
         return returncode, stdout.getvalue()
 
     @patch("rosdistro.get_index_url", get_dummy_index_url)
     @patch("rosdistro.get_index", get_dummy_index)
     @patch("rosdistro.get_cached_distribution", raise_io_error)
     def run_catkin_lint_without_rosdistro(self, *argv):
+        print("RUN:" + " ".join(argv))
         catkin_lint.environment._cache = None  # force cache reloads
+        catkin_lint.ros._rosdistro_cache = {}
         parser = prepare_arguments(argparse.ArgumentParser())
         args = parser.parse_args(argv)
         stdout = StringIO()
         with patch("sys.stdout", stdout):
             with patch("sys.stderr", stdout):
                 returncode = run_linter(args)
+        print(stdout.getvalue())
         return returncode, stdout.getvalue()
 
     def setUp(self):
@@ -159,7 +168,7 @@ class CatkinInvokationTest(unittest.TestCase):
         os.makedirs(catkin_lint.environment._cache_dir)
         os.environ = {
             "PATH": "/usr/bin:/bin",
-            "ROS_DISTRO": "kinetic",
+            "ROS_DISTRO": "melodic",
             "HOME": self.homedir,
             "ROS_PACKAGE_PATH": self.upstream_ws_srcdir,
         }
@@ -183,7 +192,7 @@ class CatkinInvokationTest(unittest.TestCase):
         exitcode, stdout = self.run_catkin_lint()
         self.assertEqual(exitcode, 0)
         self.assertIn("checked 1 packages and found 0 problems", stdout)
-        with patch("catkin_lint.linter.CMakeLinter._read_file", self.raise_io_error):
+        with patch("catkin_lint.linter.CMakeLinter._read_file", raise_io_error):
             exitcode, stdout = self.run_catkin_lint()
         self.assertEqual(exitcode, 1)
         self.assertIn("OS error: mock exception", stdout)
@@ -192,6 +201,10 @@ class CatkinInvokationTest(unittest.TestCase):
         self.assertEqual(exitcode, 0)
         self.assertIn("checked 3 packages and found 0 problems", stdout)
 
+        exitcode, stdout = self.run_catkin_lint(self.ws_srcdir, "--json")
+        self.assertEqual(exitcode, 0)
+        self.assertIn("checked 3 packages and found 0 problems", stdout)
+
         exitcode, stdout = self.run_catkin_lint(self.ws_srcdir, "--disable-cache", "--xml")
         self.assertEqual(exitcode, 0)
         self.assertIn("</catkin_lint>", stdout)
@@ -222,7 +235,7 @@ class CatkinInvokationTest(unittest.TestCase):
         exitcode, stdout = self.run_catkin_lint("--pkg", "alpha", "--pkg", "beta")
         self.assertEqual(exitcode, 0)
         self.assertIn("checked 2 packages and found 0 problems", stdout)
-        os.environ["ROS_PACKAGE_PATH"] = self.upstream_ws
+        os.environ["ROS_PACKAGE_PATH"] = self.upstream_ws_srcdir
 
         bad_path = os.path.join(self.ws_srcdir, "does_not_exist")
         exitcode, stdout = self.run_catkin_lint(bad_path)
@@ -235,10 +248,22 @@ class CatkinInvokationTest(unittest.TestCase):
         self.assertEqual(exitcode, 0)
         self.assertIn("no packages to check", stdout)
 
+        exitcode, stdout = self.run_catkin_lint(self.ws_srcdir, "--skip-path", "alpha")
+        self.assertEqual(exitcode, 0)
+        self.assertIn("checked 2 packages and found 0 problems", stdout)
+
         exitcode, stdout = self.run_catkin_lint("--pkg", "delta", "-W0")
         self.assertEqual(exitcode, 0)
         self.assertIn("additional warning", stdout)
 
+        exitcode, stdout = self.run_catkin_lint("--pkg", "delta", "-W2", "--ignore", "suggest_catkin_depend")
+        self.assertEqual(exitcode, 0)
+        self.assertIn("messages have been ignored", stdout)
+
+        exitcode, stdout = self.run_catkin_lint("--pkg", "delta", "-W2", "--ignore", "suggest_catkin_depend", "--show-ignored")
+        self.assertEqual(exitcode, 0)
+        self.assertIn("package 'std_msgs' should be listed in catkin_package()", stdout)
+
         exitcode, stdout = self.run_catkin_lint("--pkg", "delta", "-W2", "--notice", "suggest_catkin_depend")
         self.assertEqual(exitcode, 0)
         self.assertIn("notice: package 'std_msgs' should be listed in catkin_package()", stdout)
@@ -256,8 +281,9 @@ class CatkinInvokationTest(unittest.TestCase):
 
         try:
             # The following tests will not produce meaningful results
-            # if rosdep2 is unavailable
-            import rosdep2
+            # if rosdep2 or rosdistro is unavailable
+            import rosdep2  # noqa
+            import rosdistro  # noqa
 
             exitcode, stdout = self.run_catkin_lint("--package-path", os.pathsep.join([self.ws_srcdir, self.upstream_ws_srcdir]), "--pkg", "gamma")
             self.assertEqual(exitcode, 0)
@@ -273,7 +299,7 @@ class CatkinInvokationTest(unittest.TestCase):
             exitcode, stdout = self.run_catkin_lint("--pkg", "invalid_dep")
             self.assertEqual(exitcode, 0)
 
-            exitcode, stdout = self.run_catkin_lint("--pkg", "invalid_dep", "--rosdistro", "kinetic")
+            exitcode, stdout = self.run_catkin_lint("--pkg", "invalid_dep", "--rosdistro", "melodic")
             self.assertEqual(exitcode, 1)
 
             del os.environ["ROS_DISTRO"]
@@ -281,11 +307,11 @@ class CatkinInvokationTest(unittest.TestCase):
             self.assertEqual(exitcode, 0)
             self.assertNotIn("error: unknown package", stdout)
 
-            exitcode, stdout = self.run_catkin_lint(os.path.join(self.ws_srcdir, "alpha"), "--rosdistro", "kinetic")
+            exitcode, stdout = self.run_catkin_lint(os.path.join(self.ws_srcdir, "alpha"), "--rosdistro", "melodic")
             self.assertEqual(exitcode, 1)
             self.assertIn("error: unknown package", stdout)
 
-            exitcode, stdout = self.run_catkin_lint_without_rosdistro(self.ws_srcdir, "--rosdistro", "indigo")
+            exitcode, stdout = self.run_catkin_lint_without_rosdistro(self.ws_srcdir, "--rosdistro", "melodic")
             self.assertEqual(exitcode, 0)
             self.assertIn("cannot initialize rosdistro", stdout)
 
@@ -310,6 +336,6 @@ class CatkinInvokationTest(unittest.TestCase):
         self.assertIn("Cached local paths: 0\n", stdout)
 
         del os.environ["ROS_DISTRO"]
-        exitcode, stdout = self.run_catkin_lint(self.ws_srcdir, "--rosdistro", "kinetic")
+        exitcode, stdout = self.run_catkin_lint(self.ws_srcdir, "--rosdistro", "melodic")
         self.assertEqual(exitcode, 0)
         self.assertIn("checked 3 packages and found 0 problems", stdout)
